'use client'

import React, { useEffect, useRef } from 'react'
import { motion, useAnimation, useInView } from 'framer-motion'
import Image from 'next/image'

const UniqueProductSection: React.FC = () => {
  const controls = useAnimation()
  const ref = useRef(null)
  const isInView = useInView(ref, { once: true, threshold: 0.2 })

  useEffect(() => {
    if (isInView) {
      controls.start('visible')
    }
  }, [controls, isInView])

  const containerVariants = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2
      }
    }
  }

  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.5 }
    }
  }

  return (
    <section ref={ref} className="ups-section bg-white py-20 px-4">
      <div className="ups-container max-w-6xl mx-auto flex flex-col md:flex-row items-start justify-between">
        <motion.div
          className="ups-text-content mb-10 md:mb-0 md:mr-10 md:w-1/2"
          variants={containerVariants}
          initial="hidden"
          animate={controls}
        >
          <motion.h2 
            className="ups-title text-5xl md:text-6xl lg:text-7xl font-bold text-red-600 mb-6 leading-tight"
            variants={itemVariants}
          >
            EXCLUSIVE OFFER FOR NIKE AM90ID
          </motion.h2>
          <motion.p
            className="ups-description text-lg text-gray-700 mb-6"
            variants={itemVariants}
          >
            Enjoy premium comfort and style with the Nike AM90id. Take advantage of our special offer and get 20% off when you order today.
          </motion.p>
          <motion.ul
            className="ups-features-list space-y-2"
            variants={containerVariants}
          >
            {['Available in multiple colors', 'High-quality material', 'Free shipping worldwide'].map((feature, index) => (
              <motion.li
                key={index}
                className="ups-feature-item flex items-center text-gray-700"
                variants={itemVariants}
              >
                <svg className="w-5 h-5 mr-2 text-red-600" fill="currentColor" viewBox="0 0 20 20">
                  <path fillRule="evenodd" d="M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z" clipRule="evenodd" />
                </svg>
                {feature}
              </motion.li>
            ))}
          </motion.ul>
        </motion.div>
        <motion.div
          className="ups-product-card bg-white rounded-3xl shadow-lg overflow-hidden md:w-1/2 relative"
          style={{ boxShadow: '0 10px 30px rgba(0, 0, 0, 0.1)' }}
          variants={itemVariants}
          initial="hidden"
          animate={controls}
          whileHover={{ scale: 1.05 }}
        >
          <div className="ups-card-header bg-gray-800 text-red-600 text-center py-3 text-2xl font-bold">
            Fujitsu General
          </div>
          <div className="ups-card-body p-6">
            <Image
              src="/placeholder.svg?height=300&width=400"
              alt="Fujitsu General Air Conditioning Unit"
              width={400}
              height={300}
              className="ups-product-image mb-4 w-full h-auto"
            />
            <p className="ups-discount-text text-center text-2xl font-bold text-red-600 absolute bottom-4 left-0 right-0">
              Order Now and Get 20% Discount
            </p>
          </div>
        </motion.div>
      </div>
    </section>
  )
}

export default UniqueProductSection